@@ -58,6 +58,8 @@ class Graph:
         for record in result:
             name = record['out.name']
             value = record['out.value']
+            print (name)
+            print (value)
         return name, value
     
     def do_math(self, id_key, id_value):
